Crate dyn_trie

Crate dyn_trie 

Dynamic trie in contrast to classic trie does not have fixed size alphabet associated with node.

Each node has dynamic alphabet of size as to satisfy associated branches.

Structs

Node
Tree node.
Trie
Retrieval tree implementation allowing for mapping any T to any impl Iterator<Item = char> type.

Enums

KeyErr
Key error enumeration.

Traits

InsResAide
Auxiliary trait for working with InsRes.
InsResAideEx
Extension trait to InsResAide trait.

Type Aliases

Branches
Tree node branches.
InsRes
Insert result type.